@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::WOLVERIAN;
 BEGIN {
-  $Dist::Zilla::PluginBundle::WOLVERIAN::VERSION = 'v0.0.3'; # TRIAL
+  $Dist::Zilla::PluginBundle::WOLVERIAN::VERSION = 'v0.0.5'; # TRIAL
 }
 
 use MooseX::Declare;
@@ -33,7 +33,10 @@ class Dist::Zilla::PluginBundle::WOLVERIAN
             remove => ["MakeMaker"]
         });
 
-        $self->add_bundle("Git");
+        $self->add_bundle(Git => {
+            tag_format  => '%v',
+            tag_message => '%v'
+        });
 
         $self->add_plugins(qw/
             ModuleBuild
@@ -75,7 +78,7 @@ Dist::Zilla::PluginBundle::WOLVERIAN - Dist::Zilla according to wolverian
 
 =head1 VERSION
 
-version v0.0.3
+version v0.0.5
 
 =head1 AUTHOR
 
